@@ -467,14 +467,44 @@ define("orion/editor/actions", [ //$NON-NLS-0$
 			if (!annotationModel) { return true; }
 			var list = editor.getOverviewRuler() || editor.getAnnotationStyler();
 			if (!list) { return true; }
-			function ignore(annotation) {
-				return !!annotation.lineStyle ||
-					annotation.type === AT.ANNOTATION_MATCHING_BRACKET ||
-					annotation.type === AT.ANNOTATION_CURRENT_BRACKET ||
-					!list.isAnnotationTypeVisible(annotation.type);
+
+			function ignore(annotation, iterationMode) {
+				switch (iterationMode) {
+					case AT.ANNOTATION_ERROR:
+						return annotation.type !== AT.ANNOTATION_ERROR && annotation.type !== AT.ANNOTATION_WARNING;
+					case AT.ANNOTATION_READ_OCCURRENCE:
+						return annotation.type !== AT.ANNOTATION_READ_OCCURRENCE && annotation.type !== AT.ANNOTATION_WRITE_OCCURRENCE;
+					case AT.ANNOTATION_CURRENT_SEARCH:
+						return annotation.type !== AT.ANNOTATION_CURRENT_SEARCH && annotation.type !== AT.ANNOTATION_MATCHING_SEARCH;
+					case AT.ANNOTATION_TASK:
+						return annotation.type !== AT.ANNOTATION_TASK && annotation.type !== AT.ANNOTATION_BOOKMARK;
+				}
+				return true;
 			}
+			
 			var model = editor.getModel();
 			var currentOffset = editor.getCaretOffset();
+
+			// reset the iteration mode if the cursor moves between invocations			
+			if (!this._lastPosition || this._lastPosition !== currentOffset) {
+				var curAnnotations = annotationModel.getAnnotations(currentOffset, currentOffset);
+				var theMode = null;
+				while (curAnnotations.hasNext()) {
+					var annotation = curAnnotations.next();
+					if (annotation.type === AT.ANNOTATION_ERROR || annotation.type === AT.ANNOTATION_WARNING) {
+						theMode = AT.ANNOTATION_ERROR;
+						break;
+					} else if (annotation.type === AT.ANNOTATION_READ_OCCURRENCE || annotation.type === AT.ANNOTATION_WRITE_OCCURRENCE) {
+						theMode = AT.ANNOTATION_READ_OCCURRENCE;
+					} else if (annotation.type === AT.ANNOTATION_TASK || annotation.type === AT.ANNOTATION_BOOKMARK && theMode !== AT.ANNOTATION_READ_OCCURRENCE) {
+						theMode = AT.ANNOTATION_TASK;
+					} else if (annotation.type === AT.ANNOTATION_CURRENT_SEARCH || annotation.type === AT.ANNOTATION_MATCHING_SEARCH && !theMode) {
+						theMode = AT.ANNOTATION_CURRENT_SEARCH;
+					}
+				}
+				this._iterationMode = theMode ?  theMode : AT.ANNOTATION_ERROR; // Iterate Errors / Warnings by default;
+			}
+
 			var annotations = annotationModel.getAnnotations(forward ? currentOffset : 0, forward ? model.getCharCount() : currentOffset);
 			var foundAnnotation = null;
 			while (annotations.hasNext()) {
@@ -484,7 +514,7 @@ define("orion/editor/actions", [ //$NON-NLS-0$
 				} else {
 					if (annotation.start >= currentOffset) { continue; }
 				}
-				if (ignore(annotation)) {
+				if (ignore(annotation, this._iterationMode)) {
 					continue;
 				}
 				foundAnnotation = annotation;
@@ -497,12 +527,13 @@ define("orion/editor/actions", [ //$NON-NLS-0$
 				annotations = annotationModel.getAnnotations(foundAnnotation.start, foundAnnotation.start);
 				while (annotations.hasNext()) {
 					annotation = annotations.next();
-					if (annotation !== foundAnnotation && !ignore(annotation)) {
+					if (annotation !== foundAnnotation && !ignore(annotation, this._iterationMode)) {
 						foundAnnotations.push(annotation);
 					}
 				}
 				var view = editor.getTextView();
 				var tooltip = mTooltip.Tooltip.getTooltip(view, editor);
+				this._lastPosition = foundAnnotation.start;
 				if (!tooltip) {
 					editor.moveSelection(foundAnnotation.start);
 					return true;
